Index: pyyaml/trunk/tests/lib3/test_constructor.py
===================================================================
--- pyyaml/trunk/tests3/test_constructor.py	(revision 329)
+++ pyyaml/trunk/tests/lib3/test_constructor.py	(revision 330)
@@ -13,6 +13,7 @@
 def _make_objects():
     global MyLoader, MyDumper, MyTestClass1, MyTestClass2, MyTestClass3, YAMLObject1, YAMLObject2,  \
-            AnObject, AnInstance, AState, ACustomState, NewArgs, NewArgsWithState,  \
-            Reduce, ReduceWithState, MyInt, MyList, MyDict, FixedOffset, execute
+            AnObject, AnInstance, AState, ACustomState, InitArgs, InitArgsWithState,    \
+            NewArgs, NewArgsWithState, Reduce, ReduceWithState, MyInt, MyList, MyDict,  \
+            FixedOffset, execute
 
     class MyLoader(yaml.Loader):
@@ -157,4 +158,8 @@
         def __setstate__(self, state):
             self.baz = state
+
+    InitArgs = NewArgs
+
+    InitArgsWithState = NewArgsWithState
 
     class Reduce(AnObject):
